@@ -3,7 +3,7 @@ package Catalyst::View::GD::Barcode::QRcode;
 use strict;
 use warnings;
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 use base qw(Catalyst::View);
 
@@ -16,13 +16,11 @@ sub new {
     my ($class, $c, $args) = @_;
     my $self = $class->next::method($c, $args);
 
-    for my $field (keys %$args) {
-        if ($self->can($field)) {
-            $self->$field($args->{$field});
-        } else {
-            $c->log->debug("Unknown config parameter $field") if $c->debug;
-        }
-    }
+    $self->ecc($args->{ecc});
+    $self->version($args->{version});
+    $self->module_size($args->{module_size});
+    $self->img_type($args->{img_type});
+
     return $self
 }
 
